Immutable Core
==============

.. automodule:: shoobx.immutable.immutable

   .. autofunction:: update

   .. autoclass:: ImmutableBase
      :members:
      :special-members:
      :undoc-members:
      :member-order: bysource
      :exclude-members: __dict__, __implemented__, __module__, __provides__,
                        __providedBy__, __weakref__

      See :class:`shoobx.immutable.interfaces.IImmutable`

   .. autoclass:: Immutable
      :show-inheritance:
      :members:
      :special-members:
      :undoc-members:
      :member-order: bysource
      :exclude-members: __dict__, __implemented__, __module__, __provides__,
                        __providedBy__, __weakref__

      See :class:`shoobx.immutable.interfaces.IImmutableObject`

   .. autoclass:: ImmutableDict
      :show-inheritance:

   .. autoclass:: ImmutableSet
      :show-inheritance:

   .. autoclass:: ImmutableList
      :show-inheritance:
